==> xcdsutils-1.0.48.tgz: package/ebike/XCEBikeToolsPermission.js <==
/**
 * 共享工具权限配置管理
 */
const Sequelize = require('sequelize');

const xcSequelize = null;

const CREATE_RULE = {
    freezeTableName: false
}

const ROLE_TYPE = {
    //出厂检测
    //巡检
    //运营
    //管理员
}

const TOOLS_PERMISSION_DAO = {
    toolname:{
        type:Sequelize.STRING(32),
        allowNull:false
    },
    tel:{
        type:Sequelize.STRING(11),
        allowNull:false
    },
    username:{
        type:Sequelize.STRING(32),
        allowNull:false
    },
    role:{
        type:Sequelize.STRING(16),
        allowNull:false
    },
    etc:{
        type: Sequelize.STRING(1024),
        allowNull:true
    }
}

class XCEBikeToolsPermission {
    constructor(agentId){
        this.agentId = agentId;
    }

    /**
     * 配置类的redis和mysql数据库的实例
     * @param {*} redisClient 
     * @param {*} sequelizeInstance 
     */
    static configRedis(sequelizeInstance) {
        xcSequelize = sequelizeInstance;
    }

    createToolsPermissionDAO(){
        let model = sequelizeInstance.define(`tools_permission_${this.agentId}`,TOOLS_PERMISSION_DAO,CREATE_RULE);
        return model;
    }

    /**
     * 取消授权
     * @param {string} toolname 
     * @param {string} tel 
     */
    async revokePermission(toolname, tel){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.destroy({
            where:{
                toolname:toolname,
                tel:tel,
                username:username
            }
        });
        return ret;
    }

    /**
     * 授予权限
     * @param {string} toolname 
     * @param {string} tel 
     * @param {string} username 
     */
    async grantPermission(toolname, tel, username){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.create({
            toolname:toolname,
            tel:tel,
            username:username
        });
        return ret;
    }

    /**
     * 查询权限
     * @param {string} toolname 
     * @param {string} tel 
     * @param {string} username 
     */
    async hasPermission(toolname, tel, username){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.findAll({
            where:{
                toolname:toolname,
                tel:tel,
                username:username
            }
        });
        return ret;
    }

    /**
     * 判断是否是管理员
     * @param {string} toolname 
     * @param {string} tel 
     */
    async isAdmin(toolname, tel){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.findAll({
            where:{
                toolname:toolname,
                tel:tel,
                role: 'admin'
            }
        });
        return ret;
    }
}

module.exports = {
    XCEBikeToolsPermission,
}

==> xcdsutils-1.0.50.tgz: package/ebike/XCEBikeToolsPermission.js <==
/**
 * 共享工具权限配置管理
 */
const Sequelize = require('sequelize');

let xcSequelize = null;

const CREATE_RULE = {
    freezeTableName: false
}

const ROLE_TYPE = {
    //出厂检测
    //巡检
    //运营
    //管理员
}

const TOOLS_PERMISSION_DAO = {
    toolname:{
        type:Sequelize.STRING(32),
        allowNull:false
    },
    tel:{
        type:Sequelize.STRING(11),
        allowNull:false
    },
    username:{
        type:Sequelize.STRING(32),
        allowNull:false
    },
    role:{
        type:Sequelize.STRING(16),
        allowNull:false
    },
    etc:{
        type: Sequelize.STRING(1024),
        allowNull:true
    }
}

class XCEBikeToolsPermission {
    constructor(agentId){
        this.agentId = agentId;
    }

    /**
     * 配置类的redis和mysql数据库的实例
     * @param {*} redisClient 
     * @param {*} sequelizeInstance 
     */
    static configSequelize(sequelizeInstance) {
        xcSequelize = sequelizeInstance;
    }

    createToolsPermissionDAO(){
        let model = sequelizeInstance.define(`tools_permission_${this.agentId}`,TOOLS_PERMISSION_DAO,CREATE_RULE);
        return model;
    }

    /**
     * 取消授权
     * @param {string} toolname 
     * @param {string} tel 
     */
    async revokePermission(toolname, tel){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.destroy({
            where:{
                toolname:toolname,
                tel:tel,
                username:username
            }
        });
        return ret;
    }

    /**
     * 授予权限
     * @param {string} toolname 
     * @param {string} tel 
     * @param {string} username 
     */
    async grantPermission(toolname, tel, username){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.create({
            toolname:toolname,
            tel:tel,
            username:username
        });
        return ret;
    }

    /**
     * 查询权限
     * @param {string} toolname 
     * @param {string} tel 
     * @param {string} username 
     */
    async hasPermission(toolname, tel, username){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.findAll({
            where:{
                toolname:toolname,
                tel:tel,
                username:username
            }
        });
        return ret;
    }

    /**
     * 判断是否是管理员
     * @param {string} toolname 
     * @param {string} tel 
     */
    async isAdmin(toolname, tel){
        let mdoel = createToolsPermissionDAO();
        let ret = await model.findAll({
            where:{
                toolname:toolname,
                tel:tel,
                role: 'admin'
            }
        });
        return ret;
    }
}

module.exports = {
    XCEBikeToolsPermission,
}
